@@ -9,7 +9,7 @@ def q1(qn=0):
         p = os.path.join('pm20_5', 'qu1')
         print(p)
         with path(
-                p,
+                'pm20_5.qu1',
                 'q1_task1.png'
                 ) as pt:
             img = Image(filename=pt)
